import { sleep } from 'k6'

import { Rate, Trend } from 'k6/metrics'

import { loginOryGetAuthHeaders } from './utils.js'
import { home } from './home/home.js'
import { spaces } from './spaces/spaces.js'
import { profile } from './profile/profile.js'

export const options = {
  scenarios: {
    default: {
      executor: 'ramping-vus',
      startVUs: 0,
      stages: [
        { duration: '1m', target: 25 },
        { duration: '2m', target: 25 },
      ],
      gracefulRampDown: '1s',
      gracefulStop: '10s',
    },
  },
  thresholds: {
    http_req_failed: ['rate<0.02'], // http errors should be less than 2%
    http_req_duration: ['p(90)<2000'], // 90% of requests should be below 2s
  },
}

export const checkFailureRate = new Rate('check_failure_rate')
export const timeToFirstByte = new Trend('time_to_first_byte', true)

export function setup() {
  return loginOryGetAuthHeaders()
}

export default function (data) {
  home(data)
  sleep(Math.random())
  spaces(data)
  sleep(Math.random())
  profile(data)
}
